DESCRIPTION="The Extra Cmake Modules package contains extra CMake modules used by KDE Frameworks and other packages."
# extra-cmake-modules
# The Extra Cmake Modules package contains extra CMake modules used by KDE Frameworks and other packages.

# Contents
# Installed Programs: None
# Installed Libraries: None
# Installed DRI Driver Stubs: None
# Installed VA-API Drivers: None
# Installed GBM Backends: None
# Installed VDPAU Drivers: None
# Installed Vulkan Drivers: None
# Installed Directories: /usr/share/ECM and /usr/share/doc/ECM (if documentation was built)

# Short Descriptions
# None

# Required
# CMake-3.31.5

# Recommended
# Qt-6.8.2

# Optional
# PyQt (experimental support for building KDE Python bindings)

# Optional_Documentation
# sphinx-8.2.1

# Optional_Testing
# ReuseTool

VERSION_EXT=$(basename $PKG_EXTRA_CMAKE_MODULES .tar.xz | cut -d "-" -f 2) 

source /etc/profile

sed -i '/"lib64"/s/64//' kde-modules/KDEInstallDirsCommon.cmake

sed -e '/PACKAGE_INIT/i set(SAVE_PACKAGE_PREFIX_DIR "${PACKAGE_PREFIX_DIR}")' \
    -e '/^include/a set(PACKAGE_PREFIX_DIR "${SAVE_PACKAGE_PREFIX_DIR}")' \
    -i ECMConfig.cmake.in
	
mkdir build
cd    build

cmake -D CMAKE_INSTALL_PREFIX=/usr -D BUILD_WITH_QT6=ON ..
make


# As root:
make install

update_version_list $PKG_EXTRA_CMAKE_MODULES
